@@ -1,7 +1,7 @@
 package Perinci::Sub::Gen::AccessTable;
 
 our $DATE = '2015-07-01'; # DATE
-our $VERSION = '0.50'; # VERSION
+our $VERSION = '0.51'; # VERSION
 
 use 5.010001;
 use strict;
@@ -175,7 +175,7 @@ _
         func_meta   => $func_meta,
         langs       => $langs,
         name        => 'fields',
-        type        => ['array*' => {of=>'str*'}],
+        type        => ['array*' => {of=>['str*', in=>[keys %{$table_spec->{fields}}]]}],
         default     => $opts->{default_fields},
         aliases     => $opts->{fields_aliases},
         cat_name    => 'field-selection',
@@ -1483,7 +1483,7 @@ Perinci::Sub::Gen::AccessTable - Generate function (and its metadata) to read ta
 
 =head1 VERSION
 
-This document describes version 0.50 of Perinci::Sub::Gen::AccessTable (from Perl distribution Perinci-Sub-Gen-AccessTable), released on 2015-07-01.
+This document describes version 0.51 of Perinci::Sub::Gen::AccessTable (from Perl distribution Perinci-Sub-Gen-AccessTable), released on 2015-07-01.
 
 =head1 SYNOPSIS
 
